==> haskell-crypto-pubkey-0.2.8-101-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey
version: 0.2.8
id: crypto-pubkey-0.2.8-wPG2nibxh3BZjShTPthjN
key: crypto-pubkey-0.2.8-wPG2nibxh3BZjShTPthjN
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-pubkey
synopsis: Public Key cryptography
description:
    Public Key cryptography
    .
    Supports RSA PKCS15, RSA OAEP, RSA PSS, DSA, ElGamal signature.
    .
    Also have primitive support for Diffie Hellman, and ElGamal encryption
category: Cryptography
abi: 953980d29b7eb345ceacab41486de920
exposed: True
exposed-modules:
    Crypto.PubKey.DH Crypto.PubKey.DSA Crypto.PubKey.ECC.DH
    Crypto.PubKey.ECC.ECDSA Crypto.PubKey.ECC.Generate
    Crypto.PubKey.ECC.Prim Crypto.PubKey.HashDescr
    Crypto.PubKey.MaskGenFunction Crypto.PubKey.RSA
    Crypto.PubKey.RSA.OAEP Crypto.PubKey.RSA.PKCS15
    Crypto.PubKey.RSA.PSS Crypto.PubKey.RSA.Prim
hidden-modules: Crypto.PubKey.ElGamal Crypto.PubKey.RSA.Types
                Crypto.PubKey.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-0.2.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-0.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-pubkey-0.2.8
hs-libraries: HScrypto-pubkey-0.2.8-wPG2nibxh3BZjShTPthjN
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 crypto-numbers-0.2.7-475EamL4Z5s2du8VqHHmMH
    crypto-pubkey-types-0.4.3-JSfNxSxhcaEDS0tKb7tJLA
    crypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333
    cryptohash-0.11.9-1fS4JiGaDcAJHAOawh1aUA
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey/html/crypto-pubkey.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-crypto-pubkey-0.2.8-103-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-crypto-pubkey.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: crypto-pubkey
version: 0.2.8
id: crypto-pubkey-0.2.8-G9iM62d8ZbOBjkbV5fSBNk
key: crypto-pubkey-0.2.8-G9iM62d8ZbOBjkbV5fSBNk
license: BSD-3-Clause
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: Vincent Hanquez <vincent@snarc.org>
author: Vincent Hanquez <vincent@snarc.org>
homepage: https://github.com/vincenthz/hs-crypto-pubkey
synopsis: Public Key cryptography
description:
    Public Key cryptography
    .
    Supports RSA PKCS15, RSA OAEP, RSA PSS, DSA, ElGamal signature.
    .
    Also have primitive support for Diffie Hellman, and ElGamal encryption
category: Cryptography
abi: b482ba77eaa0745e0325f0c7269061a8
exposed: True
exposed-modules:
    Crypto.PubKey.DH Crypto.PubKey.DSA Crypto.PubKey.ECC.DH
    Crypto.PubKey.ECC.ECDSA Crypto.PubKey.ECC.Generate
    Crypto.PubKey.ECC.Prim Crypto.PubKey.HashDescr
    Crypto.PubKey.MaskGenFunction Crypto.PubKey.RSA
    Crypto.PubKey.RSA.OAEP Crypto.PubKey.RSA.PKCS15
    Crypto.PubKey.RSA.PSS Crypto.PubKey.RSA.Prim
hidden-modules: Crypto.PubKey.ElGamal Crypto.PubKey.RSA.Types
                Crypto.PubKey.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-0.2.8
library-dirs: /usr/lib/ghc-8.6.5/site-local/crypto-pubkey-0.2.8
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/crypto-pubkey-0.2.8
hs-libraries: HScrypto-pubkey-0.2.8-G9iM62d8ZbOBjkbV5fSBNk
depends:
    base-4.12.0.0 byteable-0.1.1-9guyEXUUK503mzSnI32g2S
    bytestring-0.10.8.2 crypto-numbers-0.2.7-475EamL4Z5s2du8VqHHmMH
    crypto-pubkey-types-0.4.3-HmTNiAOsYSfKbvyphnzlo9
    crypto-random-0.0.9-FSRi3sZKB1WKoeGDHG0333
    cryptohash-0.11.9-1fS4JiGaDcAJHAOawh1aUA
haddock-interfaces: /usr/share/doc/haskell-crypto-pubkey/html/crypto-pubkey.haddock
haddock-html: /usr/share/doc/haskell-crypto-pubkey/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
